<a id="top"></a>
<br />

<div align="center">
  <h1>django-ptpython</h1>
  <p align="center">
    PtPython as default Django shell.
    <br />
    <br />
    <a href="https://github.com/reganto/django-ptpython/issues">Report Bug</a>
  </p>
</div>

<!-- Getting Started -->

## Getting Started

### Install the Package

Install it via pip:

```bash
pip install django-ptpython
```

### Install the App

Add `django-ptpython` to your `INSTALLED_APPS` setting:

```python
INSTALLED_APPS = [
    # ...
    "django_ptpython",
    # ...
]
```

<!-- USAGE EXAMPLES -->

## Usage

```bash
./manage shell
```

![screenshot](https://user-images.githubusercontent.com/29402115/164965563-5d2091ef-e880-49a3-bef9-f1fc49419e54.png)

<!-- LICENSE -->

## License

Distributed under the Apache License. See [LICENSE](https://github.com/reganto/django-ptpython/blob/master/LICENSE.txt) for more information.

<!-- CONTACT -->

## Contact

Email: tell.reganto[at]gmail[dotcom]

<p align="right">(<a href="#top">back to top</a>)</p>
